@@ -51,7 +51,9 @@ EXTERNAL_APPS = [
     'django.contrib.staticfiles',
     'django.contrib.sitemaps',
     'django.contrib.sites',
+    'django_libs',
     'django_nose',
+    'generic_positions',
     'hvad',
 ]
 
